==> tecfy_core_package-0.1.65.tar.gz: lib/views/message/chat_contacts.page.dart <==
part of tecfy_core_client_package;

class ChatContactsPage extends StatefulWidget {
  @override
  _ChatContactsPageState createState() => _ChatContactsPageState();
}

class _ChatContactsPageState extends State<ChatContactsPage> {
  List<User> users;

  @override
  void initState() {
    loadUsers();
    super.initState();
  }

  loadUsers() async {
    var result =
        await EntityService.getData(EntityService.getEntity('tecfyUser'));
    if (result.success) {
      users = result.data.map<User>((d) => User.fromJson(d)).toList();
      setState(() {});
    } else
      result.showMessage(context);
  }

  @override
  Widget build(BuildContext context) {
    return BasePage(context, AppLocale.translate(context, 'Message Contacts'),
        //appBar: MainAppBar(context:context,title:),
        child: users == null
            ? Center(
                child: CircularProgressIndicator(
                    valueColor:
                        AlwaysStoppedAnimation<Color>(ThemeService.mainColor)))
            : ListView(
                children: users
                    .map((user) => ListTile(
                          title: Text(user.fullName),
                          onTap: () {
                            AppNavigator.navigateTo(
                                context,
                                () => ChatPage(User(
                                    id: user.id, fullName: user.fullName)));
                          },
                        ))
                    .toList(),
              ));
  }
}

==> tecfy_core_package-1.0.1.tar.gz: lib/views/message/chat_contacts.page.dart <==
part of tecfy_core_client_package;

class ChatContactsPage extends StatefulWidget {
  @override
  _ChatContactsPageState createState() => _ChatContactsPageState();
}

class _ChatContactsPageState extends State<ChatContactsPage> {
  List<User>? users;

  @override
  void initState() {
    loadUsers();
    super.initState();
  }

  loadUsers() async {
    var result =
        await EntityService.getData(EntityService.getEntity('tecfyUser'));
    if (result.success) {
      users = result.data?.map<User>((d) => User.fromJson(d)).toList();
      setState(() {});
    } else
      result.showMessage(context);
  }

  @override
  Widget build(BuildContext context) {
    return BasePage(context, AppLocale.translate(context, 'Message Contacts'),
        //appBar: MainAppBar(context:context,title:),
        child: users == null
            ? Center(
                child: CircularProgressIndicator(
                    valueColor:
                        AlwaysStoppedAnimation<Color>(ThemeService.mainColor)))
            : ListView(
                children: users
                        ?.map((user) => ListTile(
                              title: Text(user.fullName),
                              onTap: () {
                                AppNavigator.navigateTo(
                                    context,
                                    () => ChatPage(User(
                                        id: user.id, fullName: user.fullName)));
                              },
                            ))
                        .toList() ??
                    [],
              ));
  }
}
